@@ -37,6 +37,7 @@ struct cmd {
 	const char *section;
 	const char *name;
 	const char *args;
+	const char *help;
 	const enum nl80211_commands cmd;
 	int nl_msg_flags;
 	int hidden;
@@ -54,22 +55,33 @@ struct cmd {
 
 #define ARRAY_SIZE(ar) (sizeof(ar)/sizeof(ar[0]))
 
-#define __COMMAND(sect, symname, name, args, nlcmd, flags, hidden, idby, handler)\
+#define __COMMAND(_section, _symname, _name, _args, _nlcmd, _flags, _hidden, _idby, _handler, _help)\
 	static const struct cmd						\
-	__cmd ## _ ## symname ## _ ## handler ## _ ## nlcmd ## _ ## idby ## _ ## hidden\
-	__attribute__((used)) __attribute__((section("__cmd")))		\
-	= { sect, name, args, nlcmd, flags, hidden, idby, handler }
-#define COMMAND(section, name, args, cmd, flags, idby, handler)	\
-	__COMMAND(#section, name, #name, args, cmd, flags, 0, idby, handler)
-#define HIDDEN(section, name, args, cmd, flags, idby, handler)	\
-	__COMMAND(#section, name, #name, args, cmd, flags, 1, idby, handler)
-#define TOPLEVEL(name, args, cmd, flags, idby, handler)		\
-	__COMMAND(NULL, name, #name, args, cmd, flags, 0, idby, handler)
+	__cmd ## _ ## _symname ## _ ## _handler ## _ ## _nlcmd ## _ ## _idby ## _ ## _hidden\
+	__attribute__((used)) __attribute__((section("__cmd")))	= {	\
+		.section = (_section),					\
+		.name = (_name),					\
+		.args = (_args),					\
+		.cmd = (_nlcmd),					\
+		.nl_msg_flags = (_flags),				\
+		.hidden = (_hidden),					\
+		.idby = (_idby),					\
+		.handler = (_handler),					\
+		.help = (_help),					\
+	 }
+#define COMMAND(section, name, args, cmd, flags, idby, handler, help)	\
+	__COMMAND(#section, name, #name, args, cmd, flags, 0, idby, handler, help)
+#define HIDDEN(section, name, args, cmd, flags, idby, handler)		\
+	__COMMAND(#section, name, #name, args, cmd, flags, 1, idby, handler, NULL)
+#define TOPLEVEL(name, args, cmd, flags, idby, handler, help)		\
+	__COMMAND(NULL, name, #name, args, cmd, flags, 0, idby, handler, help)
 extern struct cmd __start___cmd;
 extern struct cmd __stop___cmd;
 
 extern const char iw_version[];
 
+extern int iw_debug;
+
 int handle_cmd(struct nl80211_state *state, enum id_input idby,
 	       int argc, char **argv);
 __u32 listen_events(struct nl80211_state *state,
@@ -87,4 +99,7 @@ int nl_get_multicast_id(struct nl_sock *sock, const char *family, const char *gr
 
 char *reg_initiator_to_string(__u8 initiator);
 
+const char *get_reason_str(uint16_t reason);
+const char *get_status_str(uint16_t status);
+
 #endif /* __IW_H */
